@@ -11,7 +11,7 @@ class CallBackMgr(object):
     before_request_func_list = None
     after_request_func_list = None
     teardown_request_func_list = None
-    after_loop_func_list = None
+    after_poll_func_list = None
 
     def __init__(self):
         self.rule_map = dict()
@@ -19,7 +19,7 @@ class CallBackMgr(object):
         self.before_request_func_list = []
         self.after_request_func_list = []
         self.teardown_request_func_list = []
-        self.after_loop_func_list = []
+        self.after_poll_func_list = []
 
     def add_route_rule(self, endpoint=None, view_func=None, **options):
         assert view_func is not None, 'expected view func if endpoint is not provided.'
@@ -72,9 +72,9 @@ class CallBackMgr(object):
         self.teardown_request_func_list.append(f)
         return f
 
-    def after_loop(self, f):
+    def after_poll(self, f):
         """
         一次loop结束之后
         """
-        self.after_loop_func_list.append(f)
+        self.after_poll_func_list.append(f)
         return f
