@@ -148,12 +148,12 @@ class GourdTcp(asyncore.dispatcher, CallBackMgr):
 
         while self._map:
             poll_fun(constants.LOOP_TIMEOUT, self._map)
-            # after_loop_func_list
-            for func in self.server.after_loop_func_list:
+            # after_poll_func_list
+            for func in self.server.after_poll_func_list:
                 try:
                     func()
                 except Exception, e:
-                    self.server.logger.error('after_loop_func_list raise exception. func: %s, e: %s, traceback: %s',
+                    self.server.logger.error('after_poll_func_list raise exception. func: %s, e: %s, traceback: %s',
                                              func.__name__, e, __import__('traceback').format_exc())
 
 
@@ -243,12 +243,12 @@ class GourdUdp(asyncore.dispatcher, CallBackMgr):
 
         while self._map:
             poll_fun(constants.LOOP_TIMEOUT, self._map)
-            # after_loop_func_list
-            for func in self.server.after_loop_func_list:
+            # after_poll_func_list
+            for func in self.server.after_poll_func_list:
                 try:
                     func()
                 except Exception, e:
-                    self.server.logger.error('after_loop_func_list raise exception. func: %s, e: %s, traceback: %s',
+                    self.server.logger.error('after_poll_func_list raise exception. func: %s, e: %s, traceback: %s',
                                              func.__name__, e, __import__('traceback').format_exc())
 
 
